lint

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package lint implements the "lint" command. It identifies a climax-based application, parses its source files into an AST, and reports structural drift from the current scaffold templates in unified-diff format.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	*root.Config
	Flags   *ff.FlagSet
	Command *ff.Command
}

Config holds the configuration for the lint command.

func New

func New(parent *root.Config) *Config

New creates and registers the lint command with the given parent config.

Jump to